#
# spec file for package o2scl
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define shlib lib%{name}0
Name:           o2scl
Version:        0.921
Release:        lp150.3.1
Summary:        Object-oriented Scientific Computing Library
License:        GPL-3.0-only
Group:          Productivity/Scientific/Math
Url:            http://web.utk.edu/~asteine1/o2scl
Source:         https://github.com/awsteiner/o2scl/releases/download/v%{version}/%{name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM o2scl-decrease-fit_fix-tolerances.patch gh#awsteiner/o2scl#7 badshah400@opensuse.org -- Decrease the tolerance level on fit_fix test to prevent errors on 32-bit systems; patch taken from upstream git
Patch0:         o2scl-decrease-fit_fix-tolerances.patch
BuildRequires:  armadillo-devel
BuildRequires:  eigen3-devel
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  hdf5-devel
%if 0%{?suse_version} > 1320
BuildRequires:  libboost_headers-devel
%else
BuildRequires:  boost-devel
%endif
BuildRequires:  pkgconfig
BuildRequires:  readline-devel
BuildRequires:  pkgconfig(gsl)
Recommends:     %{name}-doc = %{version}

%description
O2scl is a C++ library for object-oriented numerical programming. It
includes interpolation, differentiation, integration, roots of
polynomials, equation solving, minimization, constrained minimization,
Monte Carlo integration, simulated annealing, least-squares fitting,
solution of ordinary differential equations, two-dimensional
interpolation, Chebyshev approximation, unit conversions, and file I/O
with HDF5.

%package -n %{shlib}
Summary:        Shared libraries for O2scl, a scientific computation library
Group:          System/Libraries

%description -n %{shlib}
O2scl is a C++ library for object-oriented numerical programming.

This package provides the shared libraries for %{name}.

%package devel
Summary:        Source and header files for O2scl
Group:          Development/Libraries/C and C++
Requires:       %{shlib} = %{version}
Requires:       armadillo-devel
Requires:       eigen3-devel
Requires:       gcc-c++
Requires:       hdf5-devel
Requires:       readline-devel
Requires:       pkgconfig(gsl)

%description devel
O2scl is a C++ library for object-oriented numerical programming.

This package provides the source and header files for writing software
using %{name}.

%package doc
Summary:        Documentation for %{name}
Group:          Documentation/HTML

%description doc
O2scl is a C++ library for object-oriented numerical programming.
This package provides the documentation for %{name}.

%prep
%setup -q
%patch0 -p1

%build
%configure \
%if 0%{?suse_version} >= 1500
  --enable-gsl2 \
%endif
  --enable-eigen \
  --disable-static
make %{?_smp_mflags}

%install
%make_install
mkdir -p %{buildroot}%{_docdir}/%{name}
mv %{buildroot}%{_datadir}/doc/o2scl/* %{buildroot}%{_docdir}/%{name}/

# REMOVE BOGUS DUPLICATD DOC
rm -fr %{buildroot}%{_prefix}/search

# Remove Makefile junk
find %{buildroot}%{_docdir}/%{name}/ -name "Makefile.*" -delete -print

# Remove static libs and libtool archives
find %{buildroot}%{_libdir} "(" -name "*.a" -o -name "*.la" ")" -delete -print

%fdupes %{buildroot}%{_docdir}/%{name}/

# Tests fail on i586/arm*/aarch64/ppc* due to tolerances in the test codes being set too low. Enable only for x86_64 until fixed
%ifarch x86_64
%check
make %{?_smp_mflags} check
%endif

%post -n %{shlib} -p /sbin/ldconfig
%postun -n %{shlib} -p /sbin/ldconfig

%files -n %{shlib}
%{_libdir}/*.so.*

%files devel
%doc AUTHORS ChangeLog README NEWS COPYING
%{_libdir}/*.so
%{_includedir}/o2scl/
%{_bindir}/acol
%{_datadir}/%{name}/

%files doc
%doc %{_docdir}/%{name}/

%changelog
* Tue Apr 24 2018 guillaume.gardet@opensuse.org
- Enable test only on x86_64 since all other archs do not support
  low tolerances
* Tue Mar 27 2018 badshah400@gmail.com
- Disable tests on i586 until test codes are fixed, typically
  simply by increasing tolerances (gh#awsteiner/o2scl#7).
* Tue Mar  6 2018 badshah400@gmail.com
- Add o2scl-decrease-fit_fix-tolerances.patch: Decrease the
  tolerance level on fit_fix test to prevent errors on 32-bit
  systems during make check; patch taken from upstream git
  (gh#awsteiner/o2scl#7).
* Tue Mar  6 2018 badshah400@gmail.com
- Only enable gsl2 features for openSUSE >= 1500; gsl >= 2.0 is
  not available for older openSUSE.
* Tue Feb 27 2018 badshah400@gmail.com
- Update to version 0.921:
  * New vector_autocorr() functions were created to analyze
    autocorrelations.
  * The class serach_vec now has improved thread safety.
  * Kriging classes interpm_krige_nn, interpm_krige, and
    interp_krige were created. These are still a bit experimental.
  * A new Robbins-Monro iteration root-finding class has been
    created. A class smooth_func for smoothing multivariate
    functions by averaging in a neighborhood has been created.
    These should help dealing with noisy functions.
  * All 'funct11' classes have been renamed to 'funct'.
  * New vector bin size functions have been created.
  * The 'acol' command has been reworked to handle HDF5 I/O for
    more types. It can now manipulate vectors, matrices, and
    tensors in several new ways. The interaction with o2graph in
    o2sclpy has also been improved.
  * The Markov chain Monte Carlo classes have been updated, but
    are still experimental. Similarly with the probability
    density distribution classes where new bivariate gaussian
    and AMR-like probability densities were created.
  * The internal bibliography mechanics have been improved.
  * Error handling in nucleus_rmf has been improved.
  * Updates to eos_tov_vectors, eos_had_rmf, eos_tov_vectors,
    eos_had_skyrme.
  * Created an eos_cs2_poly class and anneal_para_ts.
  * Nuclear masses were updated for the 2016 AME data set.
  * The calculation of dndT, dndmu, and dsdT for relativistic
    fermions has been improved.
  * The SFHo and SFHx EOSs were updated.
  * Several internal changes have been made to allow Ubuntu-style
    packages. The 'make check' target now works without 'make
    install'. A snapcraft snap has also been created. These are
    still in progress.
- Run tests in a check section.
- Remove bogus duplicated doc files from non-std location
  [/usr/search].
* Tue Aug 29 2017 jengelh@inai.de
- Upgrade RPM groups; combine two find calls.
* Fri Aug 25 2017 badshah400@gmail.com
- Fix package groups: shared library -> System/Libraries, devel
  package -> Productivity/Scientific/Math.
* Thu Aug 10 2017 badshah400@gmail.com
- Use boost-devel instead of libboost_headers-devel where the
  latter is not available (openSUSE < 1320).
* Tue Aug  8 2017 badshah400@gmail.com
- Initial package.
